OC.L10N.register(
    "calendar",
    {
    "Calendar" : "カレンダー",
    "%s has published the calendar »%s«" : "%sをカレンダー »%s«に登録しました",
    "Hello," : "こんにちは。",
    "We wanted to inform you that %s has published the calendar »%s«." : "%sがカレンダー»%s«に登録されましたのでお知らせします。",
    "Open »%s«" : "»%s«を開く",
    "Cheers!" : "それでは！",
    "Recipient" : "受信者",
    "Too many redirects. Aborting ..." : "リダイレクトが多すぎます。 中止します...",
    "The remote server did not give us access to the calendar (HTTP {%s} error)" : "リモートサーバーのカレンダーにアクセスできませんでした（HTTP {%s}エラー）",
    "Error connecting to remote server" : "リモートサーバーに接続中にエラーが発生しました",
    "Error requesting resource on remote server. This could possible be related to a certificate mismatch" : "リモートサーバー上のリソースを要求中にエラーが発生しました。 これは証明書の不一致に関連する可能性があります",
    "Error requesting resource on remote server" : "リモートサーバー上のリソースを要求中にエラーが発生しました",
    "Individual" : "個人",
    "Group" : "グループ",
    "Resource" : "リソース",
    "Room" : "部屋",
    "Unknown" : "不明",
    "Required" : "必須",
    "Optional" : "オプション",
    "Does not attend" : "出席しない",
    "{name} ({email})" : "{name} ({email})",
    "You are in an unknown timezone ({tz}), falling back to UTC" : "タイムゾーン ({tz})が不明です，UTCを代替にします｡",
    "Please create a calendar first." : "初めにカレンダーを作成してください",
    "New event" : "新しいイベント",
    "CalDAV address for clients" : "クライアントのCalDAVアドレス",
    "Some events in this calendar are broken. Please check the JS console for more info." : "このカレンダーのいくつかのイベントは壊れています。 JSコンソールで詳細を確認してください。",
    "Share Calendar" : "カレンダーを共有する",
    "Shared" : "共有中",
    "Could not save WebCal-calendar" : "WebCalカレンダーを保存できませんでした",
    "WebDAV address for subscriptions" : "サブスクリプションのWebDAVアドレス",
    "Email sent." : "メールを送信しました。",
    "Could not send your email." : "あなたの電子メールを送信できませんでした。",
    "group" : "グループ",
    "Details" : "詳細",
    "Attendees" : "参加者",
    "Reminders" : "リマインダー",
    "Repeating" : "繰り返し",
    "When shared show full event" : "共有時にすべてのイベントを表示",
    "When shared show only busy" : "共有時に実行中のみを表示",
    "When shared hide this event" : "共有時にこのイベントを隠す",
    "Confirmed" : "確認済み",
    "Tentative" : "暫定的",
    "Cancelled" : "キャンセル済",
    "Please add a title." : "タイトルをつけてください。",
    "Please select a calendar." : "カレンダーを選択してください。",
    "The event can not end before it starts." : "イベントは開始前に終了できません。",
    "Global" : "全般",
    "None" : "なし",
    "Every day" : "毎日",
    "Every week" : "毎週",
    "Every month" : "毎月",
    "Every year" : "毎年",
    "never" : "なし",
    "after" : "後",
    "Automatic ({timezone})" : "自動 ({timezone})",
    "How about getting started by importing some calendars?" : "カレンダーをインポートして始めませんか？",
    "At time of event" : "イベント時",
    "5 minutes before" : "5分前",
    "10 minutes before" : "10分前",
    "15 minutes before" : "15分前",
    "30 minutes before" : "30分前",
    "1 hour before" : "1 時間前",
    "2 hours before" : "2時間前",
    "Custom" : "カスタム",
    "Audio" : "オーディオ",
    "Email" : "メール",
    "Pop-up" : "ポップアップ",
    "sec" : "秒",
    "min" : "最低",
    "hours" : "時間",
    "days" : "日",
    "week" : "週",
    "before" : "前",
    "start" : "開始",
    "end" : "終了",
    "Editing reminders of unknown type not supported." : "未知のタイプのリマインダの編集はサポートされていません。",
    "Week {number} of {year}" : "{year}の{number} 週",
    "Successfully imported {imported} objects" : "{imported}オブジェクトを正常にインポートしました",
    "Imported {imported} out of {all}, skipped one duplicate" : "{all} のうち {inported} されたものがインポートされました。",
    "Imported {imported} out of {all}, one failure" : "{all} のうち {imported} インポートされたもの、1つの失敗",
    "Imported {imported} out of {all}, {errors} failures" : "{all}、{errors}のうち{import}がインポートされました",
    "Audio alarm {time} before the event starts" : "イベントが始まる前にオーディオアラーム {time}",
    "Pop-up {time} before the event starts" : "イベント開始前に {time} ポップアップ",
    "Email {time} before the event starts" : "イベントが開始される前に {time} までメールしてください",
    "None {time} before the event starts" : "イベントが開始される前に {time} はありません",
    "{type} {time} before the event starts" : "イベント開始の{type} {time} 前",
    "Audio alarm {time} before the event ends" : "イベントが終了する前にオーディオアラーム {time}",
    "Pop-up {time} before the event ends" : "イベントが終了する前に {time} ポップアップ",
    "Email {time} before the event ends" : "イベントが終了する前にメール {time}",
    "None {time} before the event ends" : "イベントが終了する前に {time} はありません",
    "{type} {time} before the event ends" : "イベント終了の{type} {time} 前",
    "Audio alarm {time} after the event starts" : "イベント開始後のオーディオアラーム {time}",
    "Pop-up {time} after the event starts" : "イベント開始後のポップアップ {time}",
    "Email {time} after the event starts" : "イベントが開始された後にメール {time}",
    "None {time} after the event starts" : "イベント開始後は {time} なし",
    "{type} {time} after the event starts" : "イベント開始の{type} {time} 後",
    "Audio alarm {time} after the event ends" : "イベント終了後のオーディオアラーム {time}",
    "Pop-up {time} after the event ends" : "イベント終了後のポップアップ{time}",
    "Email {time} after the event ends" : "イベントが終了した後にメール {time}",
    "None {time} after the event ends" : "イベントが終了した後は {time} はありません",
    "{type} {time} after the event ends" : "イベント終了の{type} {time} 後",
    "Audio alarm at the event's start" : "イベント開始時のオーディオアラーム",
    "Pop-up at the event's start" : "イベント開始時のポップアップ",
    "Email at the event's start" : "イベント開始時にメールを送信する",
    "None at the event's start" : "イベント開始時には何もありません",
    "{type} at the event's start" : "{type} イベント開始時",
    "Audio alarm at the event's end" : "イベント終了時のオーディオアラーム",
    "Pop-up at the event's end" : "イベント終了時のポップアップ",
    "Email at the event's end" : "イベント終了時にメールを送信する",
    "None at the event's end" : "イベント終了時には何もありません",
    "{type} at the event's end" : "{type} イベント終了時",
    "Audio alarm at {time}" : "{time} のオーディオアラーム",
    "Pop-up at {time}" : "{time} のポップアップ",
    "Email at {time}" : "{time} にメールを送信",
    "None at {time}" : "{time} には何もありません",
    "{type} at {time}" : "{type} {time} 時",
    "{calendar} shared by {owner}" : "{owner} が共有中の{calendar} ",
    "Please enter a valid WebCal-URL" : "有効なWebCal-URLを入力してください",
    "Severe error in webcal proxy. Please contact administrator for more information." : "webcalプロキシの重大なエラーです。 詳細については、管理者にお問い合わせください。",
    "A Calendar app for Nextcloud" : "NextCloudのカレンダーアプリ",
    "Title of the Event" : "イベントのタイトル",
    "Starts" : "開始",
    "Ends" : "終了",
    "All day Event" : "終日イベント",
    "Delete" : "削除",
    "Cancel" : "キャンセル",
    "More ..." : "さらに表示 ...",
    "Create" : "作成",
    "Update" : "アップデート",
    "Close" : "閉じる",
    "Location" : "場所",
    "Description" : "説明",
    "Event status" : "イベントステータス",
    "Visibility when sharing" : "共有時の可視性",
    "Export" : "エクスポート",
    "%s has published the calendar %s" : "%sはカレンダー%sを公開しました",
    "We wanted to inform you that %s has published the calendar {boldstart}%s{boldend}." : "%s が {boldstart}%s{boldend} カレンダーを公開したので通知します。",
    "Click here to access it" : "それにアクセスするにはここをクリック",
    "We wanted to inform you that %s has published the calendar %s." : "%sはカレンダー%sを公開しました",
    "Click on the link below to access it" : "それにアクセスするには下をクリック",
    "Day" : "日",
    "Week" : "週",
    "Month" : "月",
    "Today" : "今日",
    "More" : "もっと見る",
    "Edit" : "編集",
    "Link" : "リンク",
    "iCal link" : "iCal リンク",
    "Download" : "ダウンロード",
    "Share with users or groups" : "ユーザーまたはグループと共有",
    "can edit" : "編集を許可",
    "Share link" : "URLで共有",
    "Public access" : "パブリックアクセス",
    "Email link to person" : "電子メールリンク",
    "Send" : "送信",
    "New Calendar" : "新しいカレンダーを作成",
    "Name" : "名前",
    "New Subscription" : "新しい購読",
    "Go back" : "戻る",
    "Go forward" : "進む",
    "Calendar does not exist" : "カレンダーが存在しません。",
    "Maybe you got a wrong link or the calendar was unshared?" : "リンクが間違っているかカレンダーが共有されていないようです。",
    "Edit event" : "イベントを編集",
    "Delete Event" : "イベントを削除",
    "Save Event" : "イベントを保存",
    "Time" : "時刻",
    "Type" : "種類",
    "Relative" : "相対指定",
    "Absolute" : "絶対指定",
    "Repeat" : "繰り返し",
    "times every" : "繰り返し",
    "Email reminders have not been implemented in the CalDAV server yet, so none will be sent." : "メールリマインダはまだCalDAVサーバーに実装されていないため、送信されません。",
    "Add" : "追加",
    "Email address of attendee" : "参加者のメールアドレス",
    "Please add your email address in the personal settings in order to add attendees." : "出席者に追加するにはアカウント設定でメールアドレスを追加してください",
    "from" : "差出人",
    "to" : "宛先",
    "This event's repeating rule is not supported yet." : "イベントの繰り返しルールはまだサポートされていません。",
    "Support for advanced rules will be added with subsequent updates." : "高度なルールのサポートが追加され、その後のアップデートが追加されます。",
    "Reset repeating rule" : "繰り返し規則のリセット",
    "Repeat every ..." : "繰り返し…",
    "end repeat ..." : "繰り返しの終わり...",
    "times" : "回数",
    "Import Calendars" : "カレンダーのインポート",
    "Import canceled" : "インポートをキャンセルしました",
    "Analyzing calendar" : "カレンダーの解析中",
    "The file contains objects incompatible with the selected calendar" : "指定したカレンダーに互換性のない情報がファイルに含まれています",
    "New calendar" : "新しいカレンダー",
    "File is empty" : "ファイルが空です",
    "File could not be parsed" : "File could not be parsed",
    "Import scheduled" : "スケジュールのインポート",
    "%s shared the calendar <strong>%s</strong> with you" : "%sはカレンダー<strong>%s</strong>をあなたと共有しています。",
    "Embed" : "埋め込み",
    "Iframe to integrate" : "Iframeの統合",
    "Publish URL" : "URLを公開する",
    "Settings & import" : "設定とインポート",
    "Import calendar" : "カレンダーのインポート",
    "No Calendars selected for import" : "インポートするカレンダーが指定されていません",
    "Skip simple event editor" : "シンプルイベントエディタをスキップ",
    "Show week numbers" : "週番号を表示する",
    "Timezone" : "タイムゾーン",
    "Primary CalDAV address" : "一番目の CalDAV アドレス",
    "iOS/macOS CalDAV address" : "iOS / macOS CalDAVアドレス",
    "Subscribe" : "購読"
},
"nplurals=1; plural=0;");
